@@ -160,9 +160,7 @@ class Restaurant(HashableModel):
             return "-"
 
         open_time = next(time for time in opening_times if time.type == TimesType.OPEN)
-        close_time = next(
-            time for time in opening_times if time.type == TimesType.CLOSE
-        )
+        close_time = next(time for time in opening_times if time.type == TimesType.CLOSE)
 
         return f"{open_time.format()} - {close_time.format()}"
 
@@ -186,14 +184,10 @@ class Restaurant(HashableModel):
     def format_rating(self) -> str:
         if not self.rating:
             return "-"
-        return (
-            f"{self.rating.text} ({self.rating.score} / {self.rating.volume} reviews)"
-        )
+        return f"{self.rating.text} ({self.rating.score} / {self.rating.volume} reviews)"
 
     def format_tags(self) -> str:
-        return ", ".join(
-            f"[black on yellow]{tag.capitalize()}[/]" for tag in self.food_tags
-        )
+        return ", ".join(f"[black on yellow]{tag.capitalize()}[/]" for tag in self.food_tags)
 
     def format_allowed_payment_methods(self) -> str:
         return ", ".join(map(str.capitalize, self.allowed_payment_methods))
